@@ -1,11 +1,11 @@
-use crate::{AgentError, RequestId};
+use crate::{ic_types::Principal, AgentError, RequestId};
 
-use crate::agent::replica_api::Certificate;
-use crate::agent::{Replied, RequestStatusResponse};
-use crate::bls::bls12381::bls;
-use crate::hash_tree::{Label, LookupResult};
-use std::str::from_utf8;
-use std::sync::Once;
+use crate::{
+    agent::{replica_api::Certificate, Replied, RequestStatusResponse},
+    bls::bls12381::bls,
+    hash_tree::{Label, LookupResult},
+};
+use std::{str::from_utf8, sync::Once};
 
 const DER_PREFIX: &[u8; 37] = b"\x30\x81\x82\x30\x1d\x06\x0d\x2b\x06\x01\x04\x01\x82\xdc\x7c\x05\x03\x01\x02\x01\x06\x0c\x2b\x06\x01\x04\x01\x82\xdc\x7c\x05\x03\x02\x01\x03\x61\x00";
 const KEY_LENGTH: usize = 96;
@@ -45,7 +45,7 @@ pub fn extract_der(buf: Vec<u8>) -> Result<Vec<u8>, AgentError> {
 
 pub(crate) fn lookup_canister_info(
     certificate: Certificate,
-    canister_id: ic_types::Principal,
+    canister_id: Principal,
     path: &str,
 ) -> Result<Vec<u8>, AgentError> {
     let path_canister = vec!["canister".into(), canister_id.into(), path.into()];
